#
# spec file for package perl-WWW-Mechanize
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name WWW-Mechanize
Name:           perl-WWW-Mechanize
Version:        2.180.0
Release:        2.2
%define cpan_version 2.18
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Handy web browsing in a Perl object
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/O/OA/OALDERS/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(HTML::Form) >= 6.08
BuildRequires:  perl(HTML::HeadParser)
BuildRequires:  perl(HTML::TokeParser)
BuildRequires:  perl(HTML::TreeBuilder) >= 5
BuildRequires:  perl(HTTP::Cookies)
BuildRequires:  perl(HTTP::Daemon) >= 6.12
BuildRequires:  perl(HTTP::Request) >= 1.30
BuildRequires:  perl(HTTP::Request::Common)
BuildRequires:  perl(LWP)
BuildRequires:  perl(LWP::Simple)
BuildRequires:  perl(LWP::UserAgent)
BuildRequires:  perl(Path::Tiny)
BuildRequires:  perl(Test::Deep)
BuildRequires:  perl(Test::Fatal)
BuildRequires:  perl(Test::Memory::Cycle)
BuildRequires:  perl(Test::More) >= 0.96
BuildRequires:  perl(Test::Output)
BuildRequires:  perl(Test::Taint) >= 1.08
BuildRequires:  perl(Test::Warnings)
BuildRequires:  perl(URI)
BuildRequires:  perl(URI::Escape)
BuildRequires:  perl(URI::URL)
BuildRequires:  perl(URI::file)
Requires:       perl(HTML::Form) >= 6.08
Requires:       perl(HTML::HeadParser)
Requires:       perl(HTML::TokeParser)
Requires:       perl(HTML::TreeBuilder) >= 5
Requires:       perl(HTTP::Cookies)
Requires:       perl(HTTP::Request) >= 1.30
Requires:       perl(HTTP::Request::Common)
Requires:       perl(LWP::UserAgent)
Requires:       perl(URI::URL)
Requires:       perl(URI::file)
Provides:       perl(WWW::Mechanize) = %{version}
Provides:       perl(WWW::Mechanize::Image) = %{version}
Provides:       perl(WWW::Mechanize::Link) = %{version}
%undefine       __perllib_provides
Recommends:     perl(Compress::Zlib)
%{perl_requires}

%description
'WWW::Mechanize', or Mech for short, is a Perl module for stateful
programmatic web browsing, used for automating interaction with websites.

Features include:

* All HTTP methods
* High-level hyperlink and HTML form support, without having to parse
  HTML yourself
* SSL support
* Automatic cookies
* Custom HTTP headers
* Automatic handling of redirections
* Proxies
* HTTP authentication

Mech is well suited for use in testing web applications. If you use one of
the Test::*, like Test::HTML::Lint modules, you can check the fetched
content and use that as input to a test call.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CONTRIBUTORS README.md
%license LICENSE

%changelog
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Wed Jan 31 2024 Tina Müller <timueller+perl@suse.de>
- updated to 2.18
  see /usr/share/doc/packages/perl-WWW-Mechanize/Changes
  2.18      2024-01-30 14:29:44Z
    [FIXED]
  - Fix click_button non exclusive attributes (GH#371) (Andreas  Huber)
    [TESTS]
  - Remove t/untaint.t (GH#377) (Olaf Alders)
* Fri Apr 28 2023 Tina Müller <timueller+perl@suse.de>
- updated to 2.17
  see /usr/share/doc/packages/perl-WWW-Mechanize/Changes
  2.17      2023-04-27 15:45:01Z
    [ENHANCEMENTS]
  - Perltidied the entire dist, and enabled tests for it (Julien Fiegehenn)
* Tue Feb 14 2023 Tina Müller <timueller+perl@suse.de>
- updated to 2.16
  see /usr/share/doc/packages/perl-WWW-Mechanize/Changes
  2.16      2023-02-11 12:09:16Z
    [FIXED]
  - Raise minimum Perl to 5.8 to match what we test, what dependencies
    depend on, etc. (GH#352) (James Raspass)
    [ENHANCEMENTS]
  - New method delete() that allows DELETE requests with Mechanize::Link
    objects (GH#361) (Stuart A Johnston)
    [DOCUMENTATION]
  - Clarify documentation for select() (GH#77) (Julien Fiegehenn)
  - Various POD fixes (Julien Fiegehenn)
  - Explain that :content-file does not decode content (GH#363) (bscan)
    [TESTS]
  - Test that follow_link(n=> 'all') warns (Kueppo Tcheukam)
  - Drop Test::Warn prerequisite and only use Test::Warnings (GH#360) (Graham Knop)
* Mon Aug 22 2022 Tina Müller <timueller+perl@suse.de>
- updated to 2.15
  see /usr/share/doc/packages/perl-WWW-Mechanize/Changes
  2.15      2022-08-21 07:47:35Z
    [FIXED]
  - There was a test suite failure on some Windows machines introduced in
    2.14 that is now fixed. (GH#350) (Julien Fiegehenn)
    [ENHANCEMENTS]
  - form_with and all_forms_with() now support the "action" attribute to find
    forms (GH#349) (Julien Fiegehenn)
  2.14      2022-08-15 19:19:24Z
    [FIXED]
  - File upload fields now correctly handle overwriting the file name and
    passing in content without a real file (GH#249) (Gil Magno and Julien
    Fiegehenn)
  - HTML::Form bumped to 6.08 (GH#347) (Julien Fiegehenn)
    [ENHANCEMENTS]
  - Add autocheck() to enable or disable autochecking at run time in
    addition to setting it at object creation (GH#232) (Julien Fiegehenn)
  - mech_dump now errors appropriately when it cannot open a URL or file
    instead of claiming it has the wrong MIME type (GH#292) (Julien Fiegehenn)
  2.13      2022-07-29 09:44:46Z
    [ENHANCEMENTS]
  - mech_dump now treats all local files like HTML regardless of what it
    thinks their content types are (GH#63) (Julien Fiegehenn)
  - We now consistently use our own die() method and therefore the onerror
    handler wherever possible (GH#80) (Julien Fiegehenn)
    [TESTS]
  - Add tests for field() when working on a <textarea> (GH#220) (Julien
    Fiegehenn)
* Thu Jul 21 2022 Tina Müller <timueller+perl@suse.de>
- updated to 2.12
  see /usr/share/doc/packages/perl-WWW-Mechanize/Changes
  2.12      2022-07-20 06:45:40Z
    [ENHANCEMENTS]
  - form_name(), form_id(), form_with() and form_with_fields() can now all
    return the nth instance of a form instead of always returning the first
    instance (GH#110) (Jeff Culverhouse and Julien Fiegehenn)
    [TESTS]
  - Tests using a local temporary server are now safe to use with HTTP/1.1
    and keep-alive (GH #14) (Stanislaw Pusep and Julien Fiegehenn)
  - We now use Test::Pod::LinkCheck to ensure there are no broken links in
    our documentation (GH #337) (Julien Fiegehenn)
  2.11      2022-07-17 17:25:39Z
    [FIXED]
  - tick() can now handle checkboxes without a value (GH#331) (Jordan M Adler
    and Julien Fiegehenn)
    [ENHANCEMENTS]
  - set_fields() and submit_form(with_fields => ...) can now set multiple
    choice inputs (e.g. select and radio) to the nth value (GH29) (Alastair
    Douglas and Julien Fiegehenn)
* Tue Jul  5 2022 Tina Müller <timueller+perl@suse.de>
- updated to 2.10
  see /usr/share/doc/packages/perl-WWW-Mechanize/Changes
  2.10      2022-07-04 21:06:13Z
    [ENHANCEMENTS]
  - Added form_action($action) to look up forms by regex matching $action (GH#19)
    (Mark Leighton Fisher and Julien Fiegehenn)
    [DOCUMENTATION]
  - Explain that file URIs need url encoding (GH#329) (Julien Fiegehenn and
    積丹尼 Dan Jacobson)
* Wed Jun 15 2022 Tina Müller <timueller+perl@suse.de>
- updated to 2.09
  see /usr/share/doc/packages/perl-WWW-Mechanize/Changes
  2.09      2022-06-14 14:20:04Z
    [DOCUMENTATION]
  - Various POD fixes (Julien Fiegehenn)
  2.08      2022-05-30 17:32:33Z
    [TESTS]
  - Drop CGI and HTTP::Server::Simple::CGI test dependencies (GH#327) (Graham
    Knop)
* Sat Apr 30 2022 Tina Müller <timueller+perl@suse.de>
- updated to 2.07
  see /usr/share/doc/packages/perl-WWW-Mechanize/Changes
  2.07      2022-04-29 15:39:17Z
    [FIXED]
  - Don't follow redirects in some tests (GH#326) (Olaf Alders)
* Tue Oct 26 2021 Tina Müller <timueller+perl@suse.de>
- updated to 2.06
  see /usr/share/doc/packages/perl-WWW-Mechanize/Changes
  2.06      2021-10-25 20:56:12Z
    [DOCUMENTATION]
  - Document methods that don't work with :content_file (GH#219) (Julien Fiegehenn)
* Wed Sep 22 2021 Tina Müller <timueller+perl@suse.de>
- updated to 2.05
  see /usr/share/doc/packages/perl-WWW-Mechanize/Changes
  2.05      2021-09-21 14:06:00Z
  - Update docs for protocols_allowed and protocols_forbidden (GH#323) (Olaf
    Alders)
* Sat Aug  7 2021 Tina Müller <timueller+perl@suse.de>
- updated to 2.04
  see /usr/share/doc/packages/perl-WWW-Mechanize/Changes
  2.04      2021-08-06 12:28:31Z
    [ENHANCEMENTS]
  - Add a head() method to allow relative URLs (GH#321) (Julien Fiegehenn)
    [DOCUMENTATION]
  - Document that form_id() accepts an id, not a name (GH#319) (Olaf Alders)
* Wed Nov 11 2020 Tina Müller <timueller+perl@suse.de>
- updated to 2.03
  see /usr/share/doc/packages/perl-WWW-Mechanize/Changes
  2.03      2020-11-10 14:47:04Z
    [FIXED]
  - Validate exclusive button selectors (GH#314) (Ferenc Erki)
* Wed Oct 14 2020 Tina Müller <timueller+perl@suse.de>
- updated to 2.02
  see /usr/share/doc/packages/perl-WWW-Mechanize/Changes
  2.02      2020-10-13 13:50:28Z
    [ENHANCEMENTS]
  - Add redirects() as a short to HTTP::Response->redirects (GH#116) (Julien Fiegehenn)
  - click_button( value => $foo) now also works for button tags and image buttons
    (GH#131) (Spencer Christensen) and (Julien Fiegehenn)
    [DOCUMENTATION]
  - Document that click_button() will die when it cannot find a button (GH#136) (Julien Fiegehenn)
  - Document that content() returns undef before a request was made (GH#134) (Julien Fiegehenn)
    [TESTS]
  - Add a test for dump_forms() with multiselect (GH#133) (Julien Fiegehenn)
  - Add tests for select multiple (GH#132) (Michael G. Schwern) and (Julien Fiegehenn)
  - Remove use of discouraged vars pragma (James Raspass)
  - Add tests for dump_forms() and field() with empty attributes (GH#125) (Julien Fiegehenn)
* Sat Sep 19 2020 Tina Müller <timueller+perl@suse.de>
- updated to 2.01
  see /usr/share/doc/packages/perl-WWW-Mechanize/Changes
  2.01      2020-09-18 17:51:10Z
  - Add rel filter to find_link() (GH#305) (Julien Fiegehenn)
  - Fix typos (GH#304) (Ferenc Erki)
* Wed Jun 10 2020 Tina Müller <timueller+perl@suse.de>
- updated to 2.00
  see /usr/share/doc/packages/perl-WWW-Mechanize/Changes
  2.00      2020-06-09 19:09:53Z
  - Require LWP::UserAgent 6.45 (GH#302) (Shoichi Kaji)
  1.99      2020-06-08 15:35:04Z
  - Bump HTTP::Daemon test dependency to 6.12 (GH#300) (Olaf Alders)
  1.98      2020-05-25 17:06:47Z (TRIAL RELEASE)
  - Don't make assumptions about port 80 in test (GH#299) (Olaf Alders)
* Thu May 14 2020 Tina Müller <timueller+perl@suse.de>
  updated to 1.97
  see /usr/share/doc/packages/perl-WWW-Mechanize/Changes
  1.97      2020-05-14 00:46:53Z
  - Respect CDATA[[ sections when parsing HTML (GH#298) (Max Maischein)
  - extract image links also from css (GH#12) (Jozef Kutej) and (GH#297)
    (Julien Fiegehenn)
  - s/parm/param/ in documentation (GH#295) (Olaf Alders)
* Sat Feb 22 2020 <timueller+perl@suse.de>
- updated to 1.96
  see /usr/share/doc/packages/perl-WWW-Mechanize/Changes
  1.96      2020-02-21 02:23:40Z [FIXED]
  - HTML::Form::find_input() has a 1-based index (GH#293) (Olaf Alders)
  - Fix invocation of dump_forms in mech-dump (GH#288) (積丹尼 Dan Jacobson)
  - make xt/author/eol.t pass (GH#291) (Shoichi Kaji)
    [DOCUMENTATION]
  - Fix documentation of use of undef in form_with() and all_forms_with()
    (GH#289) (積丹尼 Dan Jacobson)
* Tue Oct 29 2019 <timueller+perl@suse.de>
- updated to 1.95
  see /usr/share/doc/packages/perl-WWW-Mechanize/Changes
  1.95      2019-10-28 13:07:45Z
    [FIXED]
  - die if submit_form() called with invalid form_id (GH#287) (Olaf Alders)
* Fri Oct 11 2019 <timueller+perl@suse.de>
- updated to 1.94
  see /usr/share/doc/packages/perl-WWW-Mechanize/Changes
  1.94      2019-10-10 13:12:28Z
    [FIXED]
  - Issue #182: Don't autocheck for mech-dump so basic auth works (GH#285)
    (Julien Fiegehenn)
    [DOCUMENTATION]
  - Fix pod error reported by CPANTS. (GH#284) (Mohammad S Anwar)
* Mon Oct  7 2019 <timueller+perl@suse.de>
- updated to 1.93
  see /usr/share/doc/packages/perl-WWW-Mechanize/Changes
  1.93      2019-10-04 21:06:49Z
    [FIXED]
  - Allow images to not have a src attribute (GH#282) (Julien Fiegehenn)
    [DOCUMENTATION]
  - Pod fixes. (GH#283) (Mohammad S Anwar)
* Sat Aug 24 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.92
  see /usr/share/doc/packages/perl-WWW-Mechanize/Changes
  1.92      2019-08-24 01:00:35Z
    [FIXED]
  - Test requires HTTP::Daemon 6.05+ and uses 127.0.0.1 or [::1] according to
    server's sockdomain (GH#280) (Shoichi Kaji)
  - Install LWP::Protocol::https and fix xt/author/live/encoding.t (GH#277)
    (Shoichi Kaji)
  - Set dist trusty for old Perls on Travis (GH#279) (Shoichi Kaji)
  - Fixed pod errors as reported by CPANTS. (GH#273) (Mohammad S Anwar)
    [DOCUMENTATION]
  - Document that follow_link will die on failure with autocheck enabled (GH#271) (Olaf Alders)
    [TESTS]
  - Add a test for finding a link in a meta refresh tag (GH#275) (Olaf Alders)
* Fri Jan 11 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.91
  see /usr/share/doc/packages/perl-WWW-Mechanize/Changes
  1.91      2019-01-10 18:44:33Z
    [ENHANCEMENTS]
  - Don't install Perl::Critic and Perl::Tidy to run user tests (GH#268)
    (Julien Fiegehenn)
  - Remove redundant PodSyntaxTests (GH#265) (Andrew Grangaard)
  - Add test dependency for Perl::Tidy (GH#263) (Julien Fiegehenn)
* Thu Dec  6 2018 Stephan Kulow <coolo@suse.com>
- updated to 1.90
  see /usr/share/doc/packages/perl-WWW-Mechanize/Changes
  1.90      2018-11-12 18:02:03Z
    [DOCUMENTATION]
  - Pod fixes (GH#261) (Julien Fiegehenn)
  - Fixed pod error as reported by CPANTS. (GH#264) (Mohammad S Anwar)
    [ENHANCEMENTS]
  - Upgrade to HTML::TreeBuilder version 5 to get support for weak references in
    HTML::Element (GH#251) (Julien Fiegehenn)
* Thu Nov  8 2018 Stephan Kulow <coolo@suse.com>
- updated to 1.89
  see /usr/share/doc/packages/perl-WWW-Mechanize/Changes
  1.89      2018-10-18 19:13:34Z
    [ENHANCEMENTS]
  - Add support to find_image() and find_all_images() via 'id'
    and 'class' (GH#242) (Julien Fiegehenn)
  - Pass strict/verbose constructor args to HTML::Form (GH#256) (Julien Fiegehenn)
  - Add ability to clear history and tests for history (GH#259) (mschae94)
* Fri Oct 12 2018 Dirk Stoecker <opensuse@dstoecker.de>
- Fix build
* Sat Mar 24 2018 coolo@suse.com
- updated to 1.88
  see /usr/share/doc/packages/perl-WWW-Mechanize/Changes
  1.88      2018-03-23 15:37:25Z
  ========================================
    [FIXED]
  - tick() now dies if checkbox is not found (GH#248) (Olaf Alders)
    [DOCUMENTATION]
  - Clarify behaviour of submit_form when with_fields is supplied as an arg (GH#247) (Olaf Alders)
  - Document some "Best Practices" (GH#246) (Olaf Alders)
  - Update links in Pod. Suggest LWP::ConsoleLogger rather than LWP::Debug (GH#244) (Olaf Alders)
* Mon Feb 12 2018 coolo@suse.com
- updated to 1.87
  see /usr/share/doc/packages/perl-WWW-Mechanize/Changes
  1.87      2018-02-07 22:04:16Z
  ========================================
    [FIXED]
  - Fix typo in contributor name (GH#241) (Philippe Bruhat (BooK))
  - Fix link to Michael Schilli's article in Linux magazine (GH#240) (Bernhard Wagner)
  - Fix some section links (GH#238) (Evan Zacks)
  - Override _agent() method. (GH#236) (Сергей Романов)
  - Link to appropriate section of HTML::Form (GH#237) (Evan Zacks)
  - Make version consistent in .pm files (GH#231) (Olaf Alders)
    [ENHANCEMENTS]
  - Return form number in list context. (GH#235) (Сергей Романов)
  - Overload 'post' in order to set 'base'. (GH#111) (Stuart A Johnston)
  - Allow multiple file paths/uris in mech-dump; fixes issue 72 (GH#113) (Nik LaBelle)
  - Add docs for the output of dump_forms (GH#112) (John Beppu)
* Wed Feb  7 2018 coolo@suse.com
- updated to 1.86
  see /usr/share/doc/packages/perl-WWW-Mechanize/Changes
* Wed Nov 18 2015 malcolmlewis@opensuse.org
- Change build requires from perl(CGI) to perl-CGI to fix
  failing builds.
- Add preamble perl-CGI in cpanspec.yml.
- Add more verbose description.
* Fri Aug 28 2015 coolo@suse.com
- updated to 1.75
  see /usr/share/doc/packages/perl-WWW-Mechanize/Changes
  1.75
  ========================================
  [OTHER CHANGES]
  - WWW::Mechanize::Image and WWW::Mechanize::Link now have a defined $VERSION
  - fixed warning about the use of the encoding pragma (new in 5.22) (RT#91971)
  - fixed warning about the use of CGI::param in list context (RT#103096)
* Tue Apr 14 2015 coolo@suse.com
- updated to 1.74
  see /usr/share/doc/packages/perl-WWW-Mechanize/Changes
  1.74        2015-01-23
  ========================================
  [OTHER CHANGES]
  - updated repository link in metadata
* Fri Oct  4 2013 coolo@suse.com
- updated to 1.73
  [TESTS]
  - Update t/local/back.t to use LocalServer for 404 checking to avoid fails
  on win32. Fix by Matt S Trout, patient diagnostics and testing provided
  by jayefuu of freenode #perl
  - Blow away more proxy env vars in LocalServer, and do it on load so that
  the LWP env checking doesn't happen before we've done it.
  [OTHER CHANGES]
  - Better error when passing only one parameter to follow_link
* Sat Jun 15 2013 coolo@suse.com
- updated to 1.72
  [DEPENDENCIES]
  Bumped the HTML::Form dependency to fix failures on CentOS 5
  [ENHANCEMENTS]
  Recognise application/xhtml+xml as HTML.
  [DOCUMENTATION]
  Improved docs about support of JavaScript
  Typo fixes.
  [TESTS]
  Updated tests as oops-music.com is in utf-8 now
* Mon Sep 19 2011 coolo@suse.com
- updated to 1.70
  [ENHANCEMENTS]
  Mech now defaults to _not_ running live tests by default.
  You can still enable them by running "perl Makefile.PL --live"
  Thanks to RJBS for the suggestion
  [INTERNALS]
  The test suite for the local tests was updated
* Fri Apr 22 2011 jw@novell.com
- update to 1.68: dependencies fixed, test suite enhanced
* Wed Mar 30 2011 coolo@novell.com
- extent build requires
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Thu Nov 11 2010 chris@computersalat.de
- recreated by cpanspec 1.78
  o fixed deps
- changelog to changes file
- noarch pkg
* Sun Sep 12 2010 jw@novell.com
- update to 1.66
  * New $mech->text method returns the text from your HTML page.  The exact
    rendering of this text is simply removing all the HTML tags, but this will
    change. It's pretty ugly.  If anyone wants to work on a better-looking text
    dump, I'd love to see it.
  * Added mech-dump --text.
  * Improvements to the docs explaining explicitly about the subclassed
    methods we inherit from LWP::UserAgent.
* Fri Jul  2 2010 jw@novell.com
- update to 0.64,
  Parsing of forms has been delayed until they're actually needed.
  If don't use forms on a page, you'll no longer waste time and memory
  parsing them.
  $mech->title now caches the title of the page after parsing the
  page to find it.
  mech-dump now takes a --cookie-file parameter for keeping cookies
  between calls.
  $mech->form_name() and $mech->form_number() no longer throw warnings
  if they can't find the form specified.  They still return undef,
  though.
  More additions to the FAQ.
* Thu Oct 29 2009 jw@suse.de
- update to 0.60
* Fri Dec 19 2008 coolo@suse.de
- Update to 1.52
* Wed Jun 21 2006 jfunk@funktronics.ca
- Update to 1.18
* Fri Nov 11 2005 jfunk@funktronics.ca
- Update to 1.16
- Build for SL10
* Thu May 12 2005 jfunk@funktronics.ca
- Update to 1.12
- Build for SL93
* Fri Nov 19 2004 jfunk@funktronics.ca
- Initial release 1.04
